@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4011';
+our $VERSION = '0.4012';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -168,10 +168,21 @@ sub rest {
 
 
 sub count_in {
-    my $self = shift;
-    my $bars = shift || $self->bars;
+    my ($self, $args) = @_;
+
+    my $bars  = $self->bars;
+    my $patch = $self->closed_hh;
+
+    if ($args && ref $args) {
+        $bars  = $args->{bars}  if defined $args->{bars};
+        $patch = $args->{patch} if defined $args->{patch};
+    }
+    else {
+        $bars = $args; # given a simple integer
+    }
+
     for my $i ( 1 .. $self->beats * $bars ) {
-        $self->note( $self->quarter, $self->closed_hh );
+        $self->note( $self->quarter, $patch );
     }
 }
 
@@ -601,7 +612,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4011
+version 0.4012
 
 =head1 SYNOPSIS
 
@@ -838,9 +849,12 @@ It also keeps track of the beat count with the C<counter> attribute.
 
  $d->count_in;
  $d->count_in($bars);
+ $d->count_in({ bars => $bars, patch => $patch });
 
-Play the closed hihat for the number of beats times the given bars.
-If no bars are given, the default times the number of beats is used.
+Play a patch for the number of beats times the number of bars.
+
+If no bars are given, the object setting is used.  If no patch is
+given, the closed hihat is used.
 
 =head2 metronome38
 
